import math

class ParameterSet(dict):
    def __init__(self, *args, **kwargs):
        super(ParameterSet, self).__init__(*args, **kwargs)
        self.__dict__ = self

parameterSet = ParameterSet()

#############################################
#  Paths
#############################################
parameterSet.outputPath = '/home/klaus/Desktop/Dune_release/dune-microstructure/outputs'
parameterSet.baseName= 'homogeneous'   #(needed for Output-Filename)

#Indicator function that determines both phases
# x[0] : x-component
# x[1] : y-component
# x[2] : z-component
def indicatorFunction(x):
    # --- replace with your definition of indicatorFunction:
    return 1    #Phase1



########### Options for material phases: #################################
#     1. "isotropic"     2. "orthotropic"      3. "transversely_isotropic"   4. "general_anisotropic"
#########################################################################
## Notation - Parameter input :
# isotropic (Lame parameters) : [mu , lambda]
#         orthotropic         : [E1,E2,E3,G12,G23,G31,nu12,nu13,nu23]
# transversely_isotropic      : [E1,E2,G12,nu12,nu23]
# general_anisotropic         : full compliance matrix C
######################################################################
# --- Number of material phases
parameterSet.Phases=1
#--- Define different material phases:
#- PHASE 1
parameterSet.phase1_type="isotropic"
materialParameters_phase1 = [80, 80]



#--- define prestrain function for each phase
# (also works with non-constant values)
def prestrain_phase1(x):
    return [[1, 0, 0], [0,1,0], [0,0,1]]




#############################################
#  Grid parameters
#############################################
## numLevels : Number of Levels on which solution is computed. starting with a 2x2x2 cube mesh.
## {start,finish} computes on all grid from 2^(start) to 2^finish refinement
#----------------------------------------------------
parameterSet.numLevels= '3 3'      # computes all levels from first to second entry

#############################################
#  Assembly options
#############################################
parameterSet.set_IntegralZero = 1            #(default = false)
parameterSet.set_oneBasisFunction_Zero = 1   #(default = false)
#parameterSet.arbitraryLocalIndex = 7            #(default = 0)
#parameterSet.arbitraryElementNumber = 3         #(default = 0)

#############################################
#  Solver Options, Type: #1: CG - SOLVER , #2: GMRES - SOLVER, #3: QR - SOLVER (default), #4: UMFPACK - SOLVER
#############################################
parameterSet.Solvertype = 3        # recommended to use iterative solver (e.g GMRES) for finer grid-levels
parameterSet.Solver_verbosity = 0  #(default = 2)  degree of information for solver output


#############################################
#  Write/Output options      #(default=false)
#############################################
# --- (Optional output) write Material / prestrain / Corrector functions to .vtk-Files:
parameterSet.write_materialFunctions = 1   # VTK indicator function for material/prestrain definition
#parameterSet.write_prestrainFunctions = 1  # VTK norm of B (currently not implemented)

# --- (Additional debug output)
parameterSet.print_debug = 0  #(default=false)

# --- Write Correctos to VTK-File:  
parameterSet.write_VTK = 1

# --- (Optional output) L2Error, integral mean: 
#parameterSet.write_L2Error = 1
#parameterSet.write_IntegralMean = 1      

# --- check orthogonality (75) from paper: 
parameterSet.write_checkOrthogonality = 1

# --- Write corrector-coefficients to log-File:
#parameterSet.write_corrector_phi1 = 1
#parameterSet.write_corrector_phi2 = 1
#parameterSet.write_corrector_phi3 = 1

# --- Print Condition number of matrix (can be expensive):
#parameterSet.print_conditionNumber= 1  #(default=false)

# --- write effective quantities to Matlab-folder for symbolic minimization:
#parameterSet.write_toMATLAB = 0  # writes effective quantities to .txt-files QMatrix.txt and BMatrix.txt
